@@ -658,7 +658,7 @@ and row_field =
     | PaAny loc -> mkpat loc Ppat_any
     | <:patt@loc< $id:(<:ident@sloc< $uid:s$ >>)$ ($tup:<:patt@loc_any< _ >>$) >> ->
         mkpat loc (Ppat_construct (lident_with_loc (conv_con s) sloc)
-              (Some (mkpat loc_any Ppat_any)))
+              (Some ([], mkpat loc_any Ppat_any)))
     | PaApp loc _ _ as f ->
         let (f, al) = patt_fa [] f in
         let al = List.map patt al in
@@ -669,7 +669,7 @@ and row_field =
                 [ [a] -> a
                 | _ -> mkpat loc (Ppat_tuple al) ]
               in
-              mkpat loc (Ppat_construct li (Some a))
+              mkpat loc (Ppat_construct li (Some ([], a)))
         | Ppat_variant s None ->
             let a =
                 match al with
