@@ -107,6 +107,21 @@ module Make (Syntax : Sig.Camlp4Syntax) = struct
         | _ -> 1 ])
   ;
 
+  (* Yet another horrible hack, this one to improve error locations when parsing
+     [{ blah }] in expressions *)
+  value test_record_field =
+    Gram.Entry.of_parser "record_field" (fun strm ->
+      let rec loop = fun
+        [ [] -> ()
+        | [ (UIDENT _, _) :: [ (KEYWORD ".", _) :: rest ] ] -> loop rest
+        | [ (LIDENT _, _) :: [ (KEYWORD ("="|";"|"}"), _) :: _    ] ] -> ()
+        | [ (LIDENT _, _) ] -> ()
+        | _ -> raise Stream.Failure
+        ]
+      in
+      loop (Stream.npeek 100 strm))
+  ;
+
   value lident_colon =
      Gram.Entry.of_parser "lident_colon"
        (fun strm ->
@@ -315,7 +330,7 @@ module Make (Syntax : Sig.Camlp4Syntax) = struct
     expr: LEVEL "simple" (* LEFTA *)
       [ [ "false" -> <:expr< False >>
         | "true" -> <:expr< True >>
-        | "{"; lel = TRY [lel = label_expr_list; "}" -> lel] ->
+        | "{"; test_record_field; lel = label_expr_list; "}" ->
             <:expr< { $lel$ } >>
         | "{"; e = TRY [e = expr LEVEL "."; "with" -> e]; lel = label_expr_list; "}" ->
             <:expr< { ($e$) with $lel$ } >>
